@@ -12,7 +12,9 @@ public enum SPECIAL_CATEGORY_TYPE {
 
 	DIMENSION("DIMENSION", "DIMENSION"),
 	TIMEDIMENSION("TIMEDIMENSION", "TIMEDIMENSION"),
-	NONE("NONE", "NONE");
+	CODENAME("CODENAME", "CODENAME"),
+	NONE("NONE", "NONE"),
+	UNKNOWN("UNKNOWN", "UNKNOWN");
 	
 	private String id;
 	private String label;
